lhm-server-0.3.0 has been yanked.
LHM Server
Server for LHM to run the pipe and handle requests
Requires .NET SDK 8.0 to build, you can install this through winget using:
Server for LHM to run the pipe and handle requests
Requires .NET SDK 8.0 to build, you can install this through winget using: