lhm-server 0.1.0

Server for running LHM and allowing clients to connect to it without requiring admin rights
docs.rs failed to build lhm-server-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

LHM Server

Server for LHM to run the pipe and handle requests

Requires .NET SDK 8.0 to build, you can install this through winget using:

winget install Microsoft.DotNet.SDK.8